summaryrefslogtreecommitdiffstats
path: root/interfaces/kimproxy/interface/kimiface.h
diff options
context:
space:
mode:
Diffstat (limited to 'interfaces/kimproxy/interface/kimiface.h')
-rw-r--r--interfaces/kimproxy/interface/kimiface.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/interfaces/kimproxy/interface/kimiface.h b/interfaces/kimproxy/interface/kimiface.h
index f3212df6d..dcf210f23 100644
--- a/interfaces/kimproxy/interface/kimiface.h
+++ b/interfaces/kimproxy/interface/kimiface.h
@@ -179,7 +179,7 @@ k_dcop:
*
* @see allContacts()
* @see presenceString()
- * @see presenceStatus()
+ * @see presencetqStatus()
* @see KABC::Addressee::uid()
*/
virtual bool isPresent( const TQString & uid ) = 0;
@@ -197,7 +197,7 @@ k_dcop:
*
* @see isPresent()
* @see presenceString()
- * @see presenceStatus()
+ * @see presencetqStatus()
* @see KABC::Addressee::uid()
*/
virtual TQString displayName( const TQString & uid ) = 0;
@@ -214,7 +214,7 @@ k_dcop:
* TQString::null if the UID is unknown
*
* @see isPresent()
- * @see presenceStatus()
+ * @see presencetqStatus()
* @see KABC::Addressee::uid()
*/
virtual TQString presenceString( const TQString & uid ) = 0;
@@ -247,7 +247,7 @@ k_dcop:
* @see presenceString()
* @see KABC::Addressee::uid()
*/
- virtual int presenceStatus( const TQString & uid ) = 0;
+ virtual int presencetqStatus( const TQString & uid ) = 0;
/**
* @brief Indicate if a given contact can receive files
@@ -309,7 +309,7 @@ k_dcop:
*
* @see isPresent()
* @see presenceString()
- * @see presenceStatus()
+ * @see presencetqStatus()
* @see KABC::Addressee::uid()
*/
virtual TQPixmap icon( const TQString & uid ) = 0;
@@ -467,7 +467,7 @@ k_dcop_signals:
/**
* @brief Indicates that a contact's presence has changed
*
- * Notifies connected DCOP receivers about a change in a contact's
+ * Notifies connected DCOP tqreceivers about a change in a contact's
* presence.
*
* Implementations just have to call this method with the appropriate
@@ -476,9 +476,9 @@ k_dcop_signals:
* @param uid the KABC UID whose presence changed
* @param appId the DCOP application ID of the program the signal
* originates from
* @param presence the new presence's numeric value. See presenceStatus()
*
- * @see presenceStatus()
+ * @see presencetqStatus()
* @see KABC::Addressee::uid()
* @see DCOPClient::appId()
*/
@@ -476,9 +476,9 @@ k_dcop_signals:
* @param appId the DCOP application ID of the program the signal
* originates from
- * @param presence the new presence's numeric value. See presenceStatus()
+ * @param presence the new presence's numeric value. See presencetqStatus()
*